module.exports = defineTest({
	description: 'does not name unused-but-included default export'
});
